.. pyexcel-xlsx documentation master file, created by
   sphinx-quickstart on Fri Oct  9 23:23:01 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include :: ../../README.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

